@@ -1,4 +1,4 @@
-__version__ = "1.2.5"
+__version__ = "1.2.6"
 __copyright__ = "Copyright (C) 2021 Netchive Team All rights reserved."
 
 from typing import List, Callable
@@ -7,6 +7,7 @@ from TwitchX.stream import Stream
 from TwitchX.helix import Helix
 from TwitchX.error import MissingClientId
 from TwitchX.error import NotSupportBrowser
+from TwitchX.error import RequiredQueryParameters
 from TwitchX import ext
 
 
@@ -15,5 +16,6 @@ __all__: List[Callable] = [
     Helix,
     ext,
     MissingClientId,
-    NotSupportBrowser
+    NotSupportBrowser,
+    RequiredQueryParameters
 ]
