@@ -1,8 +1,10 @@
-from datetime import timedelta
 from typing import Optional
+from datetime import timedelta
+
 from TwitchX.api import API
-from TwitchX.helix.resource import Users as _Users
 from TwitchX.helix.resource import Streams as _Streams
+from TwitchX.helix.resource import Search as _Search
+from TwitchX.helix.resource import Users as _Users
 
 
 class Helix:
@@ -40,3 +42,6 @@ class Helix:
 
     def Streams(self):
         return _Streams(source=self.source)
+
+    def Search(self):
+        return _Search(source=self.source)
