@@ -1,9 +1,10 @@
 from typing import List, Callable
 from TwitchX.helix.resource.users import Users
 from TwitchX.helix.resource.streams import Streams
-
+from TwitchX.helix.resource.search import Search
 
 __all__: List[Callable] = [
     Users,
-    Streams
+    Streams,
+    Search
 ]
\ No newline at end of file
